/// <reference types="node" />
import { Surrializable } from 'surrial';
/**
 * Represents a file within Stryker. Could be a strictly in-memory file.
 */
export default class File implements Surrializable {
    readonly name: string;
    private _textContent;
    private readonly _content;
    /**
     * Creates a new File to be used within Stryker.
     * @param name The full name of the file (inc path)
     * @param content The buffered or string content of the file
     */
    constructor(name: string, content: Buffer | string);
    /**
     * Gets the underlying content as buffer.
     */
    get content(): Buffer;
    /**
     * Gets the underlying content as string using utf8 encoding.
     */
    get textContent(): string;
    /**
     * This fixes the issue of different File versions not being compatible.
     * @see https://github.com/stryker-mutator/stryker/issues/2025
     */
    surrialize(): string;
}
//# sourceMappingURL=File.d.ts.map