"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const surrial_1 = require("surrial");
/**
 * Represents a file within Stryker. Could be a strictly in-memory file.
 */
class File {
    /**
     * Creates a new File to be used within Stryker.
     * @param name The full name of the file (inc path)
     * @param content The buffered or string content of the file
     */
    constructor(name, content) {
        this.name = name;
        if (typeof content === 'string') {
            this._content = Buffer.from(content);
            this._textContent = content;
        }
        else {
            this._content = content;
        }
    }
    /**
     * Gets the underlying content as buffer.
     */
    get content() {
        return this._content;
    }
    /**
     * Gets the underlying content as string using utf8 encoding.
     */
    get textContent() {
        if (!this._textContent) {
            this._textContent = this.content.toString();
        }
        return this._textContent;
    }
    /**
     * This fixes the issue of different File versions not being compatible.
     * @see https://github.com/stryker-mutator/stryker/issues/2025
     */
    surrialize() {
        return surrial_1.surrial `new File(${this.name}, ${this.content})`;
    }
}
exports.default = File;
//# sourceMappingURL=File.js.map