"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.declareFactoryPlugin = exports.declareClassPlugin = void 0;
const PluginKind_1 = require("./PluginKind");
/**
 * Declare a class plugin. Use this method in order to type check the dependency graph of your plugin
 * @param kind The plugin kind
 * @param name The name of the plugin
 * @param injectableClass The class to be instantiated for the plugin
 */
function declareClassPlugin(kind, name, injectableClass) {
    return {
        injectableClass,
        kind,
        name,
    };
}
exports.declareClassPlugin = declareClassPlugin;
/**
 * Declare a factory plugin. Use this method in order to type check the dependency graph of your plugin,
 * @param kind The plugin kind
 * @param name The name of the plugin
 * @param factory The factory used to instantiate the plugin
 */
function declareFactoryPlugin(kind, name, factory) {
    return {
        factory,
        kind,
        name,
    };
}
exports.declareFactoryPlugin = declareFactoryPlugin;
//# sourceMappingURL=Plugins.js.map